@@ -2,35 +2,28 @@
 function (object, object2 = NULL, B = 49, ...) {
     if (!inherits(object, "rasch"))
         stop("Use only with 'rasch' objects.\n")
-    if (!is.null(object2)){
-        ind.rasch.obj2 <- inherits(object2, "rasch")
-        ind.ltm.obj2 <- inherits(object2, "ltm")
-        if (!ind.rasch.obj2 && !ind.ltm.obj2)
-            stop("\n", deparse(substitute(object2)), " must inherit from either class 'rasch' or class 'ltm'.")
-        if (ind.rasch.obj2 && is.null(object$constraint))
-            stop("\n", deparse(substitute(object)), " must be a constrained Rasch model in order to be nested in ", 
-                        deparse(substitute(object2)))
+    out <- if (!is.null(object2)){
+        if (!class(object2) %in% c("ltm", "rasch", "tpm"))
+            stop("'object2' must inherit from either class 'ltm', 'rasch', or 'tpm'.\n")
+        if (inherits(object2, "rasch") && is.null(object$constraint))
+            stop("'object1' should be a constrained Rasch model.\n")
         if (!isTRUE(all.equal(object$X, object2$X)))
             warning("it seems that the two objects represent models fitted in different data sets.")
-        L0 <- object$log.Lik
-        L1 <- object2$log.Lik
-        nb0 <- nrow(object$coef) + 1
-        nb1 <- if (ind.rasch.obj2) nrow(object2$coef) + 1 else length(object2$coef)
-        if (!is.null(constr <- object$constraint))
-            nb0 <- nb0 - nrow(constr)
-        if (!is.null(constr <- object2$constraint))
-            nb1 <- nb1 - nrow(constr)
+        L0 <- logLik(object)
+        L1 <- logLik(object2)
+        nb0 <- attr(L0, "df")
+        nb1 <- attr(L1, "df")
         df. <- nb1 - nb0
         if (df. < 0)
-            stop(deparse(substitute(object)), " is not nested in ", deparse(substitute(object2)))
-        LRT <- -2 * (L0 - L1)
+            stop("'object' is not nested in 'object2'.\n")
+        LRT <- - 2 * (L0 - L1)
+        attributes(LRT) <- NULL
         if (LRT < 0)
-            warning("it seems that the two models are not nested.")
+            warning("either the two models are not nested or the model represented by 'object2' fell on a local maxima.\n")
         p.value <- pchisq(LRT, df., lower.tail = FALSE)
-        out <- list(nam0 = deparse(substitute(object)), L0 = L0, aic0 = -2 * L0 + 2 * nb0, 
-                bic0 = -2 * L0 + log(nrow(object$X)) * nb0, nam1 = deparse(substitute(object2)), L1 = L1, 
-                aic1 = -2 * L1 + 2 * nb1, bic1 = -2 * L1 + log(nrow(object2$X)) * nb1, LRT = LRT, df = df., 
-                p.value = p.value, call = object$call)
+        list(nam0 = deparse(substitute(object)), L0 = L0, aic0 = AIC(object), bic0 = AIC(object, k = log(attr(L0, "n"))), 
+             nam1 = deparse(substitute(object2)), L1 = L1, aic1 = AIC(object2), 
+             bic1 = AIC(object2, k = log(attr(L1, "n"))), LRT = LRT, df = df., p.value = p.value, call = object$call)
     } else {
         if (any(is.na(object$X)) && is.null(object$na.action))
             stop("In the presense of missing values the parametric Bootstrap test is not currently implemented.\n")
@@ -70,7 +63,7 @@ function (object, object2 = NULL, B = 49, ...) {
                                     control = object$control))
         }
         p.val <- (1 + sum(Ts >= Tobs)) / (B + 1)
-        out <- list(Tobs = Tobs, p.value = p.val, B = B, call = object$call)
+        list(Tobs = Tobs, p.value = p.val, B = B, call = object$call)
     }
     class(out) <- "aov.rasch"
     out
